@@ -2,15 +2,18 @@
 import re
 import subprocess
 import sys
+from collections import OrderedDict
 from .source import Source
 from .configuration import Configuration
 import io
 import codecs
 try:
     # Python 2.x and 3.x support for checking string types
-    assert basestring
+    basestring
+    unicode
 except NameError:
     basestring = str
+    unicode = str
 
 
 class PDFKit(object):
@@ -36,7 +39,7 @@ class PDFKit(object):
             return self.msg
 
     def __init__(self, url_or_file, type_, options=None, toc=None, cover=None,
-                 css=None, configuration=None, cover_first=False):
+                 css=None, configuration=None, cover_first=False, verbose=False):
 
         self.source = Source(url_or_file, type_)
         self.configuration = (Configuration() if configuration is None
@@ -46,15 +49,19 @@ class PDFKit(object):
         except AttributeError:
             self.wkhtmltopdf = self.configuration.wkhtmltopdf
 
-        self.options = dict()
+        self.options = OrderedDict()
         if self.source.isString():
             self.options.update(self._find_options_in_meta(url_or_file))
 
-        if options is not None: self.options.update(options)
+        self.environ = self.configuration.environ
+
+        if options is not None:
+            self.options.update(options)
 
         self.toc = {} if toc is None else toc
         self.cover = cover
         self.cover_first = cover_first
+        self.verbose = verbose
         self.css = css
         self.stylesheets = []
 
@@ -83,6 +90,9 @@ class PDFKit(object):
 
         yield self.wkhtmltopdf
 
+        if not self.verbose:
+            self.options.update({'--quiet': ''})
+
         for argpart in self._genargs(self.options):
             if argpart:
                 yield argpart
@@ -122,11 +132,56 @@ class PDFKit(object):
     def command(self, path=None):
         return list(self._command(path))
 
+    @staticmethod
+    def handle_error(exit_code, stderr):
+        if exit_code == 0:
+            return
+
+        stderr_lines = stderr.splitlines()
+
+        # Sometimes wkhtmltopdf will exit with non-zero
+        # even if it finishes generation.
+        # If will display 'Done' in the second last line
+        if len(stderr_lines) > 1 and stderr.splitlines()[-2].strip() == 'Done':
+            return
+
+        if 'cannot connect to X server' in stderr:
+            raise IOError('%s\n'
+                          'You will need to run wkhtmltopdf within a "virtual" X server.\n'
+                          'Go to the link below for more information\n'
+                          'https://github.com/JazzCore/python-pdfkit/wiki/Using-wkhtmltopdf-without-X-server' % stderr)
+
+        if 'Error' in stderr:
+            raise IOError('wkhtmltopdf reported an error:\n' + stderr)
+
+        error_msg = stderr or 'Unknown Error'
+        raise IOError("wkhtmltopdf exited with non-zero code {0}. error:\n{1}".format(exit_code, error_msg))
+
     def to_pdf(self, path=None):
         args = self.command(path)
 
-        result = subprocess.Popen(args, stdin=subprocess.PIPE, stdout=subprocess.PIPE,
-                                  stderr=subprocess.PIPE)
+        if sys.platform == 'win32':
+            #hide cmd window
+            startupinfo = subprocess.STARTUPINFO()
+            startupinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
+            startupinfo.wShowWindow = subprocess.SW_HIDE
+
+            result = subprocess.Popen(
+                args,
+                stdin=subprocess.PIPE,
+                stdout=subprocess.PIPE,
+                stderr=subprocess.PIPE,
+                env=self.environ,
+                startupinfo=startupinfo
+            )
+        else:
+            result = subprocess.Popen(
+                args,
+                stdin=subprocess.PIPE,
+                stdout=subprocess.PIPE,
+                stderr=subprocess.PIPE,
+                env=self.environ
+            )
 
         # If the source is a string then we will pipe it into wkhtmltopdf.
         # If we want to add custom CSS to file then we read input file to
@@ -138,25 +193,12 @@ class PDFKit(object):
             input = self.source.source.read().encode('utf-8')
         else:
             input = None
+
         stdout, stderr = result.communicate(input=input)
-        stderr = stderr or stdout
-        try:
-            stderr = stderr.decode('utf-8')
-        except UnicodeDecodeError:
-            stderr = ''
+        stderr = stderr or stdout or b""
+        stderr = stderr.decode('utf-8', errors='replace')
         exit_code = result.returncode
-
-        if 'cannot connect to X server' in stderr:
-            raise IOError('%s\n'
-                          'You will need to run wkhtmltopdf within a "virtual" X server.\n'
-                          'Go to the link below for more information\n'
-                          'https://github.com/JazzCore/python-pdfkit/wiki/Using-wkhtmltopdf-without-X-server' % stderr)
-
-        if 'Error' in stderr:
-            raise IOError('wkhtmltopdf reported an error:\n' + stderr)
-
-        if exit_code != 0:
-            raise IOError("wkhtmltopdf exited with non-zero code {0}. error:\n{1}".format(exit_code, stderr))
+        self.handle_error(exit_code, stderr)
 
         # Since wkhtmltopdf sends its output to stderr we will capture it
         # and properly send to stdout
@@ -165,20 +207,20 @@ class PDFKit(object):
 
         if not path:
             return stdout
-        else:
-            try:
-                with codecs.open(path, encoding='utf-8') as f:
-                    # read 4 bytes to get PDF signature '%PDF'
-                    text = f.read(4)
-                    if text == '':
-                        raise IOError('Command failed: %s\n'
-                                      'Check whhtmltopdf output without \'quiet\' '
-                                      'option' % ' '.join(args))
-                    return True
-            except IOError as e:
-                raise IOError('Command failed: %s\n'
-                              'Check whhtmltopdf output without \'quiet\' option\n'
-                              '%s ' %(' '.join(args)),e)
+
+        try:
+            with codecs.open(path, encoding='utf-8') as f:
+                # read 4 bytes to get PDF signature '%PDF'
+                text = f.read(4)
+                if text == '':
+                    raise IOError('Command failed: %s\n'
+                                  'Check whhtmltopdf output without \'quiet\' '
+                                  'option' % ' '.join(args))
+                return True
+        except (IOError, OSError) as e:
+            raise IOError('Command failed: %s\n'
+                          'Check whhtmltopdf output without \'quiet\' option\n'
+                          '%s ' % (' '.join(args), e))
 
     def _normalize_options(self, options):
         """ Generator of 2-tuples (option-key, option-value).
@@ -193,7 +235,7 @@ class PDFKit(object):
         """
 
         for key, value in list(options.items()):
-            if not '--' in key:
+            if '--' not in key:
                 normalized_key = '--%s' % self._normalize_arg(key)
             else:
                 normalized_key = self._normalize_arg(key)
@@ -202,8 +244,8 @@ class PDFKit(object):
                 for optval in value:
                     yield (normalized_key, optval)
             else:
-                yield (normalized_key, str(value) if value else value)
-
+                normalized_value = '' if isinstance(value,bool) else value
+                yield (normalized_key, unicode(normalized_value) if value else value)
 
     def _normalize_arg(self, arg):
         return arg.lower()
